@@ -114,7 +114,7 @@ class Project:
         for i in range(len(self.inputs.keys)):
             self.converters.tensorboard_converters.col_to_type_mapping[self.inputs.keys[i]] = self.inputs.types[i]
         if not converters_file.exists():
-            torch.save(self.converters.state_dict(), converters_file)
+            torch.save(self.converters.state_dict(), converters_file, pickle_protocol=4)
 
     def add_task_flow(self, task_flow: TaskFlow):
         self.flow_tasks.append(task_flow)
